@@ -1,4 +1,3 @@
-# type: ignore[attr-defined]
 """Awesome `np-validator` is a Python cli/package created with https://github.com/TezRomacH/python-package-template"""
 
 import sys
@@ -9,7 +8,13 @@ else:
     import importlib_metadata
 
 from .core import run_validation
-from .dataclasses import Processor, ValidationStep, Validator, load_ValidationStep
+from .dataclasses import (
+    Processor,
+    ValidationStep,
+    Validator,
+    dump_ValidationResults,
+    load_ValidationStep,
+)
 
 
 def get_version() -> str:
@@ -20,3 +25,13 @@ def get_version() -> str:
 
 
 version: str = get_version()
+
+# needed or else mypy will complain as of 0.971
+__all__ = [
+    "run_validation",
+    "ValidationStep",
+    "Validator",
+    "Processor",
+    "load_ValidationStep",
+    "version",
+]
